==> mono_1.2.6+dfsg.orig.tar.gz: mono-1.2.6+dfsg/mcs/class/Mono.Data.Tds/Mono.Data.Tds.Protocol/TdsVersion.cs <==
//
// Mono.Data.Tds.Protocol.TdsVersionInternal.cs
//
// Author:
//   Daniel Morgan <danmorg@sc.rr.com>
//
// Copyright (C) 2002 Daniel Morgan
//

//
// Permission is hereby granted, free of charge, to any person obtaining
// a copy of this software and associated documentation files (the
// "Software"), to deal in the Software without restriction, including
// without limitation the rights to use, copy, modify, merge, publish,
// distribute, sublicense, and/or sell copies of the Software, and to
// permit persons to whom the Software is furnished to do so, subject to
// the following conditions:
// 
// The above copyright notice and this permission notice shall be
// included in all copies or substantial portions of the Software.
// 
// THE SOFTWARE IS PROVIDED "AS IS", WITHOUT WARRANTY OF ANY KIND,
// EXPRESS OR IMPLIED, INCLUDING BUT NOT LIMITED TO THE WARRANTIES OF
// MERCHANTABILITY, FITNESS FOR A PARTICULAR PURPOSE AND
// NONINFRINGEMENT. IN NO EVENT SHALL THE AUTHORS OR COPYRIGHT HOLDERS BE
// LIABLE FOR ANY CLAIM, DAMAGES OR OTHER LIABILITY, WHETHER IN AN ACTION
// OF CONTRACT, TORT OR OTHERWISE, ARISING FROM, OUT OF OR IN CONNECTION
// WITH THE SOFTWARE OR THE USE OR OTHER DEALINGS IN THE SOFTWARE.
//

namespace Mono.Data.Tds.Protocol {
	public enum TdsVersion
	{
                tds42 = 42, // used by older Sybase and Microsoft SQL (< 7.0) servers
                tds50 = 50, // used by Sybase
                tds70 = 70, // used by Microsoft SQL server 7.0/2000
                tds80 = 80  // used by Microsoft SQL server 2000
	}
}

==> mono_2.4.2.3+dfsg.orig.tar.gz: mono-2.4.2.3+dfsg/mcs/class/Mono.Data.Tds/Mono.Data.Tds.Protocol/TdsVersion.cs <==
//
// Mono.Data.Tds.Protocol.TdsVersionInternal.cs
//
// Author:
//   Daniel Morgan <danmorg@sc.rr.com>
//
// Copyright (C) 2002 Daniel Morgan
//

//
// Permission is hereby granted, free of charge, to any person obtaining
// a copy of this software and associated documentation files (the
// "Software"), to deal in the Software without restriction, including
// without limitation the rights to use, copy, modify, merge, publish,
// distribute, sublicense, and/or sell copies of the Software, and to
// permit persons to whom the Software is furnished to do so, subject to
// the following conditions:
// 
// The above copyright notice and this permission notice shall be
// included in all copies or substantial portions of the Software.
// 
// THE SOFTWARE IS PROVIDED "AS IS", WITHOUT WARRANTY OF ANY KIND,
// EXPRESS OR IMPLIED, INCLUDING BUT NOT LIMITED TO THE WARRANTIES OF
// MERCHANTABILITY, FITNESS FOR A PARTICULAR PURPOSE AND
// NONINFRINGEMENT. IN NO EVENT SHALL THE AUTHORS OR COPYRIGHT HOLDERS BE
// LIABLE FOR ANY CLAIM, DAMAGES OR OTHER LIABILITY, WHETHER IN AN ACTION
// OF CONTRACT, TORT OR OTHERWISE, ARISING FROM, OUT OF OR IN CONNECTION
// WITH THE SOFTWARE OR THE USE OR OTHER DEALINGS IN THE SOFTWARE.
//

namespace Mono.Data.Tds.Protocol {
	public enum TdsVersion
	{
		tds42 = 42, 	// used by older Sybase and Microsoft SQL (< 7.0) servers
		tds50 = 50, 	// used by Sybase
		tds70 = 70, 	// used by Microsoft SQL server 7.0/2000
		tds80 = 80, 	// used by Microsoft SQL server 2000
		tds81 = 81, 	// used by Microsoft SQL server 2000 SP1
		tds90 = 90, 	// used by Microsoft SQL server 2005
		tds100 = 100	// used by Microsoft SQL server 2008
	}
}
